Typos
authorMyhailo Danylenko <isbear@ukrpost.net>
Tue, 03 Mar 2009 23:20:29 +0200
changeset 15 b224cbc7b8be
parent 14 ff13ba17fb6d
child 16 d6d32995832b
Typos
main.c
--- a/main.c	Tue Mar 03 23:15:04 2009 +0200
+++ b/main.c	Tue Mar 03 23:20:29 2009 +0200
@@ -219,12 +219,12 @@
 }
 
 /// main.bind
 /// Sets or gets alias.
 /// You can specify nil as a command to unbind key.
 /// If you omit keycode, it will return hash table of all bindings.
 /// A: string (keycode, optional), string (command, optional)
 /// R: string (command, optional)
-static int lua_main_alias (lua_State *L)
+static int lua_main_binding (lua_State *L)
 {
 	int top = lua_gettop (L);
 	if (top > 0) {
@@ -551,7 +551,7 @@
 static int lua_main_add_category (lua_State *L)
 {
 	guint cid;
-	if (lua_gettop (L) > 0)
+	if (lua_gettop (L) > 0) {
 		luaL_argcheck (L, lua_type (L, 1) == LUA_TTABLE, 1, "table expected");
 		cid = compl_new_category ();
 		if (cid) {
@@ -568,7 +568,7 @@
 	} else
 		cid = compl_new_category ();
 	if (cid) {
-		lua_added_categories = g_slist_prepend (lua_added_categories, (gpoiner) cid);
+		lua_added_categories = g_slist_prepend (lua_added_categories, (gpointer) cid);
 		lua_pushinteger (L, cid);
 	} else
 		lua_pushnil (L);
@@ -629,7 +629,7 @@
 			if (lua_type (L, 3) == LUA_TTABLE) {
 				cid = compl_new_category ();
 				if (cid) {
-					lua_added_categories = g_slist_prepend (lua_added_categories, (gpoiner) cid);
+					lua_added_categories = g_slist_prepend (lua_added_categories, (gpointer) cid);
 					lua_pushnil (L);
 					while (lua_next (L, 3)) {
 						char *word = to_utf8 (luaL_checkstring (L, -1));
@@ -219,12 +219,12 @@
 
 /// main.bind
-/// Sets or gets alias.
+/// Sets or gets binding.
 /// You can specify nil as a command to unbind key.
 /// If you omit keycode, it will return hash table of all bindings.